-- MySQL dump 9.11
--
-- Host: pcitgm07.cern.ch    Database: fireman_db
-- ------------------------------------------------------
-- Server version	4.0.21-Max


--
-- Schema version
--
DROP TABLE IF EXISTS schema_version;
CREATE TABLE schema_version (
  major INTEGER NOT NULL,
  minor INTEGER NOT NULL,
  patch INTEGER NOT NULL
) TYPE=INNODB;
INSERT INTO schema_version (major,minor,patch) VALUES (1,5,0);

--
-- Table structure for table ACL_principals
--

DROP TABLE IF EXISTS ACL_principals;
CREATE TABLE ACL_principals (
  principal_id int(11) UNIQUE NOT NULL auto_increment,
  principalName varchar(250) UNIQUE NOT NULL COLLATE latin1_general_cs -- impose CASE sensitivity. 250 is current DN limitation 
) TYPE=InnoDB;
CREATE INDEX ACL_principals_index ON ACL_principals(principalName(250));

--
-- Table structure for table ACL_entries
--

DROP TABLE IF EXISTS ACL_entries;
CREATE TABLE ACL_entries (
  acl_id int(11) UNIQUE NOT NULL auto_increment,
  principal_id int(11) NOT NULL REFERENCES ACL_principals(principal_id),
  perm int(2) default NULL,

  UNIQUE KEY entry (principal_id,perm)
) TYPE=InnoDB;


--
-- Table structure for table BASIC_permissions
--

DROP TABLE IF EXISTS BASIC_permissions;
CREATE TABLE BASIC_permissions (
  basic_id int(11) UNIQUE NOT NULL auto_increment,
  userId int default NULL REFERENCES ACL_principals(principal_id),
  groupId int default NULL REFERENCES ACL_principals(principal_id),
  userPerm tinyint(4) UNSIGNED default NULL,
  groupPerm tinyint(4) UNSIGNED default NULL,
  otherPerm tinyint(4) UNSIGNED default NULL,
  
  UNIQUE KEY entry (userId,groupId,userPerm,groupPerm,otherPerm)
) TYPE=InnoDB;

--
-- Table structure for table GUID_acl
--

DROP TABLE IF EXISTS GUID_acl;
CREATE TABLE GUID_acl (
  guid_id int(11) default NULL,
  acl_id int(11) default NULL,
  
  UNIQUE KEY entry (guid_id,acl_id)
) TYPE=InnoDB;

--
-- Table structure for table GUID_basicPerm
--

DROP TABLE IF EXISTS GUID_basicPerm;
CREATE TABLE GUID_basicPerm (
  guid_id int(11) UNIQUE NOT NULL,
  basic_id int(11) default NULL
) TYPE=MyISAM;

--
-- Table structure for table DEFAULT_permissions
--

DROP TABLE IF EXISTS DEFAULT_permissions;
CREATE TABLE DEFAULT_permissions (
  global tinyint(11) default NULL,
  user tinyint(11) default NULL,
  acl_id int(11) default NULL,
  basic_id int(11) default NULL
) TYPE=InnoDB;

--
-- Initial values for table DEFAULT_permissions
--
INSERT INTO ACL_principals (principal_id,principalName) VALUES (1,"egee");
INSERT INTO ACL_principals (principal_id,principalName) VALUES (2,"egee-group");
INSERT INTO BASIC_permissions (basic_id,userId,groupId,userPerm,groupPerm,otherPerm) VALUES(1,1,2,255,36,0);
INSERT INTO BASIC_permissions (basic_id,userId,groupId,userPerm,groupPerm,otherPerm) VALUES(2,1,2,63,63,63);
INSERT INTO DEFAULT_permissions VALUES(1,0,0,1);
INSERT INTO DEFAULT_permissions VALUES(0,1,0,1);

--
-- Table structure for table GUID_entries
--

DROP TABLE IF EXISTS GUID_entries;
CREATE TABLE GUID_entries (
  guid_id int(11) UNIQUE NOT NULL auto_increment,
  guidName varchar(36) default NULL,
  fileSize decimal(21,0) default NULL,
  timeRowWritten timestamp(14), -- Overcome Mysql "documented" behaviour. http://bugs.mysql.com -> Bug#3019
  createTime timestamp(14) NOT NULL,
  status smallint(6) default NULL,
  modifyTime timestamp(14) NOT NULL default '00000000000000',
  checksum varchar(32) default NULL
) TYPE=InnoDB;

CREATE INDEX GUID_entries_index ON GUID_entries(guidName(12));
--
-- Table structure for table LFN_dirs
--

DROP TABLE IF EXISTS LFN_dirs;
CREATE TABLE LFN_dirs (
  dir_id int(11) UNIQUE NOT NULL auto_increment,
  dirName TEXT default NULL,
  timeRowWritten timestamp(14), -- Overcome Mysql "documented" behaviour. http://bugs.mysql.com -> Bug#3019
  creationTime timestamp(14) NOT NULL,
  guid_id int(11) default NULL,
  data TEXT,
  validityTime timestamp(14) NOT NULL default '00000000000000',
  modifyTime timestamp(14) NOT NULL default '00000000000000',
  parentDir int(11) default NULL,
  UNIQUE KEY entry (`parentDir`,`dirName`(250)) -- For dirNames with length > 250, it may still happen duplication
) TYPE=InnoDB;

CREATE INDEX LFN_dirs_index ON LFN_dirs(dirname(250));

-- 
-- Creating Root
--

INSERT INTO GUID_entries (guid_id,guidName,createTime,modifyTime) VALUES (1,"10000000-0000-0000-0000-000000000000",now(),now());
INSERT INTO GUID_entries (guid_id,guidName,createTime,modifyTime) VALUES (2,"10000000-0000-0000-0000-000000000001",now(),now());
INSERT INTO GUID_entries (guid_id,guidName,createTime,modifyTime) VALUES (3,"10000000-0000-0000-0000-000000000002",now(),now());
INSERT INTO LFN_dirs (dir_id,dirName,creationTime,guid_id,parentDir) VALUES (1,'/',now(),1,1);
INSERT INTO LFN_dirs (dir_id,dirName,creationTime,guid_id,parentDir) VALUES (2,'/tmp',now(),2,1);
INSERT INTO LFN_dirs (dir_id,dirName,creationTime,guid_id,parentDir) VALUES (3,'/free',now(),3,1);
INSERT INTO GUID_basicPerm (guid_id,basic_id) VALUES (1,1);
INSERT INTO GUID_basicPerm (guid_id,basic_id) VALUES (2,2);
INSERT INTO GUID_basicPerm (guid_id,basic_id) VALUES (3,2);

--
-- Table structure for table LFN_files
--

DROP TABLE IF EXISTS LFN_files;
CREATE TABLE LFN_files (
  file_id int(11) UNIQUE NOT NULL auto_increment,
  data TEXT,
  fileName varchar(250) default NULL,
  timeRowWritten timestamp(14), -- Overcome Mysql "documented" behaviour. http://bugs.mysql.com -> Bug#3019
  creationTime timestamp(14) NOT NULL,
  guid_id int(11) default NULL,
  parentDir int(11) default NULL,
  validityTime timestamp(14) NOT NULL default '00000000000000',
  modifyTime timestamp(14) NOT NULL default '00000000000000',
  UNIQUE KEY entry(`fileName`, `parentDir`)
) TYPE=InnoDB;

CREATE INDEX LFN_files_index ON LFN_files(fileName);
-- CREATE UNIQUE INDEX LFN_files_constraint ON LFN_files(`fileName`, `parentDir`);

--
-- Table structure for table LFN_links
--

DROP TABLE IF EXISTS LFN_links;
CREATE TABLE LFN_links (
  link_id int(11) UNIQUE NOT NULL auto_increment,
  linkName varchar(250) default NULL,
  parentDir int(11) default NULL,
  type tinyint(4) default NULL,
  destination_id int(11) default NULL,
  timeRowWritten timestamp(14), -- Overcome Mysql "documented" behaviour. http://bugs.mysql.com -> Bug#3019
  creationTime timestamp(14) NOT NULL,
  guid_id int(11) default NULL,
  data TEXT,
  validityTime timestamp(14) NOT NULL default '00000000000000',
  modifyTime timestamp(14) NOT NULL default '00000000000000',
  UNIQUE KEY entry(`linkName`,`parentDir`)
) TYPE=InnoDB;

CREATE INDEX LFN_links_index on LFN_links(linkName);
-- CREATE UNIQUE INDEX LFN_links_constraint ON LFN_links(`linkName`, `parentDir`);

--
-- Table structure for table REPLICA_relations
--

DROP TABLE IF EXISTS REPLICA_relations;
CREATE TABLE REPLICA_relations (
  surl_id int(11) UNIQUE default NULL,
  guid_id int(11) default NULL,
  UNIQUE KEY entry (guid_id,surl_id)
) TYPE=InnoDB;

--
-- Table structure for table SURL_entries
--

DROP TABLE IF EXISTS SURL_entries;
CREATE TABLE SURL_entries (
  surl_id int(11) UNIQUE NOT NULL auto_increment,
  timeRowWritten timestamp(14), -- Overcome Mysql "documented" behaviour. http://bugs.mysql.com -> Bug#3019
  modifyTime timestamp(14) NOT NULL,
  masterFlag tinyint(4) default NULL,
  createTime timestamp(14) NOT NULL default '00000000000000',
  surlName TEXT
) TYPE=InnoDB;

CREATE INDEX SURL_entries_index on SURL_entries(surlName(20));

-- 
-- Table structure for table DIR_schema
-- Relating Directories with schema
--

DROP TABLE IF EXISTS DIR_schema;
CREATE TABLE DIR_schema (
  dir_id int(11) NOT NULL REFERENCES LFN_dirs(dir_id),
  schema_id int NOT NULL REFERENCES t_schema(schema_id)
) TYPE=InnoDB;


DROP TABLE IF EXISTS GLOBAL_attributes;
CREATE TABLE GLOBAL_attributes (
   guid_id int(11) NOT NULL REFERENCES GUID_entries(guid_id),
   attributeName varchar(250),
   attributeValue varchar(250),
   attributeType varchar(100),
   UNIQUE KEY entry (guid_id,`attributeName`)
) TYPE=InnoDB;

CREATE INDEX GLOBAL_attributes on GLOBAL_attributes(attributeName);





--DROP TABLE IF EXISTS t_entry;
--CREATE TABLE t_entry (
--        entry_id                INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
--        entry_name              VARCHAR(250) UNIQUE NOT NULL,
--          schema_id               INT     NOT NULL REFERENCES t_schema(schema_id),
--          creation_time           TIMESTAMP NOT NULL
--) TYPE=INNODB;
--
----
---- Table holding schemas
----      schema_id:                      internal identifier
----      schema_name:            a unique name for referencing the schema
----      schema_description:     a longer text description of the schema ?? needed
----
--DROP TABLE IF EXISTS t_schema;
--CREATE TABLE t_schema (
--        schema_id                       INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
--        schema_name                     VARCHAR(100) NOT NULL UNIQUE
--) TYPE=INNODB;
--
-- INSERT INTO t_schema (schema_name) values ('default');

DROP TABLE IF EXISTS t_entry;
CREATE TABLE t_entry (
        entry_id                INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
        entry_name              VARCHAR(250) UNIQUE NOT NULL,
        owner_id                INT NOT NULL REFERENCES ACL_principals(principal_id),
        group_id                INT NOT NULL REFERENCES ACL_principals(principal_id),
        user_perm               TINYINT(3) UNSIGNED NOT NULL,
        group_perm              TINYINT(3) UNSIGNED NOT NULL,
        other_perm              TINYINT(3) UNSIGNED NOT NULL,
        schema_id               INT NOT NULL REFERENCES t_schema(schema_id),
        creation_time           TIMESTAMP NOT NULL
) TYPE=INNODB;

--
-- Table holding schemas
--      schema_id:                      internal identifier
--      schema_name:            a unique name for referencing the schema
--      schema_description:     a longer text description of the schema ?? needed
--
DROP TABLE IF EXISTS t_schema;
CREATE TABLE t_schema (
        schema_id                       INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
        schema_name                     VARCHAR(100) NOT NULL UNIQUE
) TYPE=INNODB;

--
-- Table holding principals
--      principal_id:   internal identifier
--      principal_name: user/client DN
--
--DROP TABLE IF EXISTS t_principal;
--CREATE TABLE t_principal (
--        principal_id    INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
--        principal_name  VARCHAR(250) UNIQUE NOT NULL
--) TYPE=INNODB;

--
-- Table holding acls
--      entry_id:               reference to the entry
--      principal_id:   reference to the principal
--      get_meta_perm:  boolean defining if given principal/client/user can get metadata for entry
--      set_meta_perm:  boolean defining if given principal/client/user can set metadata for entry
--
DROP TABLE IF EXISTS t_acl;
CREATE TABLE t_acl (
        entry_id                INT NOT NULL REFERENCES t_entry(entry_id),
        principal_id            INT NOT NULL REFERENCES ACL_principals(principal_id),
        perm                    TINYINT(3) UNSIGNED NOT NULL,
        PRIMARY KEY (entry_id, principal_id)
) TYPE=INNODB;

INSERT INTO t_schema (schema_name) VALUES ('eds_test');
