#!/usr/bin/env python
#####################################################################################
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://eu-egee.org/partners/ for details on the copyright holders.
# For license conditions see the license file or http://eu-egee.org/license.html
#
#####################################################################################
#
# upgrade script for the gLite Data Management Single Catalog Node
# Daniel Rodrigues < daniel.rodrigues@cern.ch >
#
# Version info: $Id: upgrade_glite-1.1.py,v 1.1 2005/09/16 09:58:19 dfrodrig Exp $
#
# Usage: python glite-data-single-catalog-config [-c|-v|-h|-siteconfig=<site config url>|--start|--stop|--status|--configure|--upgrade|--help]
#        -c                             print configuration
#        -v                             print version
#        -h,--help                      print usage info
#        -siteconfig=<site config url>  use site configuration file
#        --start                        start the service
#        --stop                         start the service
#        --status                       shows the status of the service
#        --configure                    configures the service
#        --upgrade                      upgrades service from 1.3 - 1.4
#
# Return codes: 0 - Ok
#               1 - Configuration failed
#
#####################################################################################

import os,string,socket,time
import sys
import getopt
import commands

from  gLiteInstallerLib import gLib
from mysql import Mysql
from tomcat5 import Secure_tomcat5
from gliteRgmaServicetool import gliteRgmaServicetool

# Set global variables here 
global params                        # all config values from the XML file
global mysql                         # the one and only mysql service instance

global verbose

class glite_data_single_catalog:

    def __init__(self):
        self.verbose = 0
        self.version = "2.0.1"
        self.name = "glite-data-single-catalog"
        self.friendly_name = "Data Management Single Catalog Service"
        self.glib = params['gLib']
        self.mysql = Mysql()
        self.tomcat = Secure_tomcat5(params)
        params['module.version'] = self.version
        
    #-------------------------------------------------------------------------------
    # Banner 
    #-------------------------------------------------------------------------------

    def banner(self):

        print "\nxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
        print "Configuring the %s" % self.friendly_name
        print "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx\n"
    
    #-------------------------------------------------------------------------------
    # Copyright 
    #-------------------------------------------------------------------------------

    def copyright(self):

        print '\nCopyright (c) Members of the EGEE Collaboration. 2004'
        print 'See http://eu-egee.org/partners/ for details on the copyright holders'
        print 'For license conditions see the license file or http://eu-egee.org/license.html'

    #-------------------------------------------------------------------------------
    # Version
    #-------------------------------------------------------------------------------

    def showVersion(self):

        print '\n%s-config  v. %s\n' % (self.name,self.version)
    

	#################################################################
	# usage 
	#
	# print usage
	#
	#################################################################
    def usage(self,msg = ""):

        if msg:
            print "\n%s" % (msg)
        
        self.copyright()
        self.showVersion()

        print "Usage: \n"
        print "Edit the configuration file %s.cfg.xml in " %  self.name,
        print "%s/etc.config/templates" % os.environ['GLITE_LOCATION']
        print "save it as %s/etc/config/%s.cfg.xml" % (os.environ['GLITE_LOCATION'], self.name),
        print "and run the script as follows"
        print "python %s-config [OPTION...]" % self.name
        print ''
        print '    -c, --checkconf     print the service configuration'
        print '    -v, --version       print the version of the configuration script'
        print '    -h, --help          print this usage information'
        print '    --configure         configure %s' % self.friendly_name
        print '    --upgrade           upgrade %s' % self.friendly_name
        print '    --start             start %s' % self.friendly_name
        print '    --stop              stop %s' % self.friendly_name
        print '    --status            print service status (0 = running, 1 = idle)'
        print '    --siteconfig=URL    use site configuration file'
        print '\n'

    
	#################################################################
	# upgrade
	#
	# upgrade data single catalog (MySQL) 1.3 - 1.4
	#
	# return 0 ok
	#        1 error
	#
	#################################################################
    def upgrade(self):
        

        #--------------------------------------------------------
	# Check configuration values
	#--------------------------------------------------------
		
        print "Checking configuration values                             ",		

        # mysql root password
        if params.has_key('mysql.root.password'):
        	mysql_root_password = params['mysql.root.password']
        else:
            mysql_root_password = ""	

        glib.printOkMessage()
        
        glib.printInfoMessage("Restarting MySQL...")
        #self.mysql.start()

	#--------------------------------------------------------
	# Upgrade all instances
	#--------------------------------------------------------
        instances = self.glib.getInstances()
        if len(instances) == 0:
            self.upgradeInstance()
        else:
            for name in instances.keys():
                self.upgradeInstance(name)
                
        return 0
    
	#################################################################
	# upgradeInstance
	#
	# upgrade one (VO) instance
	#
	# return 0 ok
	#        1 error
	#
	#################################################################    
    def upgradeInstance(self, name='default'):

        glib.printInfoMessage("Got InstanceParams %s ..." % name)
        instanceParams = self.glib.getInstanceParams(name)
        if name == 'default':
            name = 'glite-data-catalog-service-fr-mysql'

		#--------------------------------------------------------
		# Create DB if it doesn't exists or db.force.create is true
		#--------------------------------------------------------
       
        glib.printInfoMessage("DBName: %s ; rootPassword: %s" %(instanceParams['catalog-service-fr-mysql.DBNAME'],params['mysql.root.password'])) 
	#--------------------------------------------------------
	#  Call the script Upgrade script
	#--------------------------------------------------------
        os.system(". upgrade_glite-1.1.sh %s %s" %(instanceParams['catalog-service-fr-mysql.DBNAME'], params['mysql.root.password']))


        return 0

        
#-------------------------------------------------------------------------------
# Set all environment variables
#-------------------------------------------------------------------------------

def set_env():
    
    # gLite
    glib.export('GLITE_LOCATION');
    glib.export('GLITE_LOCATION_VAR');
    if not os.path.exists(os.environ['GLITE_LOCATION_VAR']):
        os.mkdir(os.environ['GLITE_LOCATION_VAR'],0755)
    glib.export('GLITE_LOCATION_LOG');
    if not os.path.exists(os.environ['GLITE_LOCATION_LOG']):
        os.mkdir(os.environ['GLITE_LOCATION_LOG'],0755)
    glib.export('GLITE_LOCATION_TMP');
    if not os.path.exists(os.environ['GLITE_LOCATION_TMP']):
        os.mkdir(os.environ['GLITE_LOCATION_TMP'],0755)

    if not params.has_key('X509_VOMS_DIR'):
        params['X509_VOMS_DIR'] = '/etc/grid-security/vomsdir'
    glib.export('X509_VOMS_DIR', params['X509_VOMS_DIR'])

    glib.export("JAVA_HOME")
    glib.export("CATALINA_HOME","/var/lib/tomcat5")

    glib.addEnvPath("PATH", "%s/bin" % os.environ["JAVA_HOME"])
    glib.addEnvPath("PATH", "%s/externals/bin" % os.environ["GLITE_LOCATION"])
    glib.addEnvPath("PATH", "%s/bin" % os.environ["GLITE_LOCATION"])

    glib.addEnvPath("LD_LIBRARY_PATH", "%s/externals/lib" % os.environ["GLITE_LOCATION"])
    glib.addEnvPath("LD_LIBRARY_PATH", "%s/lib" % os.environ["GLITE_LOCATION"])
    
    # MANPATH
    glib.addEnvPath('MANPATH', os.environ['GLITE_LOCATION'] + '/share/man')

    # Set environment
    glib.setUserEnv()

	
#################################################################
# replaceTags
#
# replace tags in file
#
# return 0 ok
#        1 error
#
#################################################################     
def replaceTags(line, params, prefix):
    if line.find("@") > -1:
        tags = line.split("@")
        i = 1
        while i < len(tags):
            if params.has_key(prefix + "." + tags[i]):
                paramName = "%s.%s" % (prefix, tags[i])
                if verbose:
                    print("Replace @%s@ by %s" % (tags[i], params[paramName]))
                line = line.replace("@%s@" % tags[i], params[paramName])
            else:
                if verbose:
                    print("Replace @%s@ by empty string" %(tags[i]))
                line = line.replace("@%s@" % tags[i], "")
            i += 2
    return line

#-------------------------------------------------------------------------------
#  Main program begins here 
#-------------------------------------------------------------------------------

if __name__ == '__main__':

    # The script must be run as root
    if not os.geteuid()==0:
        print '"\nThis script must be run as root\n'
        sys.exit(1)
        
    # Get an instance of the library class
    glib = gLib()
    glib.verbose = 0
    
	# ------------------------------------------------------------
	# Load parameters
	# ------------------------------------------------------------
    params = {}
    try:
        opts, args = glib.getopt(sys.argv[1:], '', ['siteconfig='])
        for o, a in opts:
            if o == "--siteconfig":
                params['site.config.url'] = a
                break
    except getopt.GetoptError:
        pass

    if glib.loadConfiguration("%s/../glite-data-single-catalog.cfg.xml" % glib.getScriptPath(),params):
        print "An error occurred while configuring the service"
        sys.exit(1)
    params['gLib'] = glib
    
	# ------------------------------------------------------------    
	# set verbosity
	# ------------------------------------------------------------	
    verbose = 0
    if params.has_key('glite.installer.verbose'):
        if params['glite.installer.verbose'] == "true":
            verbose = 1
    glib.verbose = verbose
    
	# ------------------------------------------------------------
	# Set up the environment
	# ------------------------------------------------------------
    set_env()
          
	# ------------------------------------------------------------	      
	# Instantiate the service classes
	# ------------------------------------------------------------
    service = glite_data_single_catalog()
    service.verbose = verbose
    
    # Instantiate the rgma servicetool class
    if params['rgma.servicetool.activate'] == 'true':
        rgmaServicetool = gliteRgmaServicetool()
        rgmaServicetool.verbose = verbose

	# ------------------------------------------------------------
	# Command line opts if any
	# ------------------------------------------------------------
    try:
        opts, args = glib.getopt(sys.argv[1:], 'chv', ['upgrade'])
    except getopt.GetoptError:
        service.usage(msg = "Unknown options(s)")
        sys.exit(1)

    if len(opts) == 0:
        service.usage()
        sys.exit(0)
    
	# ------------------------------------------------------------
	# Check cli options
	# ------------------------------------------------------------	
    for o, a in opts:
        
        if o == "--upgrade":
            # Check certificates
            service.copyright()
            service.showVersion()
            service.banner()
                
            # Configure the service
            return_value = service.upgrade()
            
            if return_value == 0:

                # Stop all services
                glib.printInfoMessage("Upgrade Successful...")
                sys.exit(0)

            elif return_value == 2:

                # Stop all services
                print "\n\nThe %s upgrade was completed, but one or more warnings" % service.friendly_name
                print "were issued. Please revise them and re-run the script"
                print "or upgrade and start the %s manually\n" % service.friendly_name

                sys.exit(2)

            else:
                print "\n\nAn unrecoverable error occurred while upgrading the %s" \
                    % service.friendly_name

                sys.exit(1)
            

